@@ -8,12 +8,24 @@
 # --------------------------------------------------------------------------------------
 from ._shared import LoraBase
 from .facet import Facet
+from .facet import FacetRead
 from .itsystem import ITSystem
 from .klasse import Klasse
+from .klasse import KlasseRead
 from .organisation import Organisation
+from .organisation import OrganisationRead
 
 # --------------------------------------------------------------------------------------
 # All
 # --------------------------------------------------------------------------------------
 
-__all__ = ["LoraBase", "Facet", "Klasse", "Organisation", "ITSystem"]
+__all__ = [
+    "LoraBase",
+    "Facet",
+    "FacetRead",
+    "Klasse",
+    "KlasseRead",
+    "Organisation",
+    "OrganisationRead",
+    "ITSystem",
+]
