@@ -6,6 +6,7 @@
 # --------------------------------------------------------------------------------------
 # Imports
 # --------------------------------------------------------------------------------------
+from typing import Optional
 from uuid import UUID
 
 from pydantic import Field
@@ -17,6 +18,7 @@ from ._shared import FacetRelations
 from ._shared import FacetStates
 from ._shared import LoraBase
 from ._shared import Published
+from ._shared import RegistrationTime
 from ._shared import Responsible
 
 
@@ -41,9 +43,9 @@ class Facet(LoraBase):
     @classmethod
     def from_simplified_fields(
         cls,
-        uuid: UUID,
         user_key: str,
         organisation_uuid: UUID,
+        uuid: Optional[UUID] = None,
         from_date: str = "-infinity",
         to_date: str = "infinity",
     ) -> "Facet":
@@ -68,3 +70,18 @@ class Facet(LoraBase):
             relations=relations,
             uuid=uuid,
         )
+
+
+class FacetRead(Facet):
+    from_time: RegistrationTime = Field(
+        alias="fratidspunkt", description="The facet registration from time."
+    )
+    to_time: RegistrationTime = Field(
+        alias="tiltidspunkt", description="The facet registration to time."
+    )
+    life_cycle_code: str = Field(
+        alias="livscykluskode", description="The facet registation life cycle code."
+    )
+    user_ref: UUID = Field(
+        alias="brugerref", description="The facet registration user."
+    )
