@@ -19,6 +19,7 @@ from ._shared import OrganisationProperties
 from ._shared import OrganisationRelations
 from ._shared import OrganisationStates
 from ._shared import OrganisationValidState
+from ._shared import RegistrationTime
 
 
 # --------------------------------------------------------------------------------------
@@ -45,9 +46,9 @@ class Organisation(LoraBase):
     @classmethod
     def from_simplified_fields(
         cls,
-        uuid: UUID,
         name: str,
         user_key: str,  # often == name,
+        uuid: Optional[UUID] = None,
         municipality_code: Optional[int] = None,
         from_date: str = "-infinity",
         to_date: str = "infinity",
@@ -79,3 +80,18 @@ class Organisation(LoraBase):
             relations=relations,
             uuid=uuid,
         )
+
+
+class OrganisationRead(Organisation):
+    from_time: RegistrationTime = Field(
+        alias="fratidspunkt", description="The facet registration from time."
+    )
+    to_time: RegistrationTime = Field(
+        alias="tiltidspunkt", description="The facet registration to time."
+    )
+    life_cycle_code: str = Field(
+        alias="livscykluskode", description="The facet registation life cycle code."
+    )
+    user_ref: UUID = Field(
+        alias="brugerref", description="The facet registration user."
+    )
