@@ -18,6 +18,7 @@ from .._shared import LeaveType
 from .._shared import MOBase
 from .._shared import PersonRef
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # Role
@@ -55,6 +56,10 @@ class LeaveWrite(LeaveBase):
     )
 
 
+class LeaveDetail(LeaveWrite, Details):
+    pass
+
+
 class Leave(MOBase):
     type_: Literal["leave"] = Field(
         "leave", alias="type", description="The object type."
